x_storage_flutter library
Classes
- XStorageAudioService
- A simple service example that plays audio only through network storage (using NetworkProviderMixin)
- XStorageImage
- A widget that automatically detects and displays images from XStorage (Asset/Network/File/Other)